import { world, ItemStack } from '@minecraft/server';

export const spawnParticle = async (particleId, target) => {
    try {
        target.dimension.spawnParticle(particleId, target.location);
    } catch (error) {
        console.warn(`Failed to spawn particle ${particleId}:`, error);
    }
};

export const spawnItem = async (itemId, target) => {
    try {
        const loc = target.location;
        target.dimension.spawnItem(
            new ItemStack(itemId, 1),
            { x: loc.x, y: loc.y, z: loc.z}
        );
    } catch (error) {
        console.warn(`Failed to spawn item ${itemId}:`, error);
    }
};

export const spawnEntity = async (entityId, target) => {
    try {
        target.dimension.spawnEntity(entityId, target.location);
    } catch (error) {
        console.warn(`Failed to spawn entity ${entityId}:`, error);
    }
};

export const isPickaxe = async (item) => {
    try {
        const tags = await item.getTags();
        return tags.includes("minecraft:is_pickaxe");
    } catch (error) {
        console.error(`[Simple Autosmelt] Error: ${error}`);
        return false;
    }
};

export const playSound = async (soundId, target) => {
    try {
        const loc = target.location;
        target.dimension.playSound(soundId, loc);
    } catch (error) {
        console.warn(`Failed to play sound ${soundId}:`, error);
    }
};